@@ -66,12 +66,13 @@ if len(sys.argv) > 1:
                         file_recv_config={}, debug_msg_counts=Connector.DEBUG_MSG_COUNTS, silent=Connector.SILENT, 
                         uds_path_receive_preserve_socket=Connector.UDS_PATH_RECEIVE_PRESERVE_SOCKET, 
                         uds_path_send_preserve_socket=Connector.UDS_PATH_SEND_PRESERVE_SOCKET,
-                        enable_client_try_reconnect=True, max_size_file_upload=Connector.MAX_SIZE_FILE_UPLOAD,
+                        enable_client_try_reconnect=True, max_size_file_upload_send=Connector.MAX_SIZE_FILE_UPLOAD_SEND,
+                        max_size_file_upload_recv=Connector.MAX_SIZE_FILE_UPLOAD_RECV, max_certs=Connector.MAX_CERTS,
                         everybody_can_send_messages=Connector.EVERYBODY_CAN_SEND_MESSAGES, send_message_types_priorities={},
                         proxy={})
         print('\n- MANAGER TEMPLATE, used to create a connector')
         print(json.dumps(manager_config_template, indent=4, sort_keys=True))
-        file_recv_config = {'any': {'target_directory':'/tmp/aioconnectors/{message_type}/{source_id}/',
+        file_recv_config = {'any': {'target_directory':'/var/tmp/aioconnectors/{message_type}/{source_id}/',
                                     'owner':'user:user', 'override_existing':False}}
         print('\n- file_recv_config example, used inside MANAGER TEMPLATE')
         print(json.dumps(file_recv_config, indent=4, sort_keys=True))                
