@@ -437,13 +437,22 @@ class FullDuplex:
                                 hook_target_directory = self.connector.hook_target_directory.get(with_file['dst_type'])                                
                                 #user should have manually defined hook_target_directory(transport_json) beforehand
                                 if hook_target_directory:
-                                    dst_dirpath = os.path.join(dst_dirpath, hook_target_directory(transport_json))
+                                    hooked_target_directory = hook_target_directory(transport_json)
+                                    if hooked_target_directory:
+                                        dst_dirpath = os.path.join(dst_dirpath, hooked_target_directory)
+                                    elif hooked_target_directory is False:
+                                        #hook_target_directory returning False means refuse this file
+                                        self.logger.warning(f'{self.connector.source_id} handle_incoming_connection from peer '
+                                                    f'{self.peername} tried to create file in directory refused by hooked_target_directory'
+                                                    f' {dst_dirpath} for type {with_file.get("dst_type")}, ignoring...')                                    
+                                        dst_dirpath = False
+                                    #else, hook_target_directory returning None means no change to dst_dirpath                                        
                         except Exception:
                             self.logger.exception('hook_target_directory')
-                        self.logger.info(f'{self.connector.source_id} handle_incoming_connection from peer '
-                                        f'{self.peername} storing file into {dst_dirpath}')
                         
                         if dst_dirpath:
+                            self.logger.info(f'{self.connector.source_id} handle_incoming_connection from peer '
+                                        f'{self.peername} storing file into {dst_dirpath}')                            
                             binary_offset = 0
                             try:
                                 if not binary:
@@ -494,7 +503,7 @@ class FullDuplex:
                                     #                        'fcreating directory {dir_dst_fullpath}')
                                     #    os.makedirs(dir_dst_fullpath)
                                     
-                                    if len(binary[binary_offset:]) > self.connector.max_size_file_upload:
+                                    if len(binary[binary_offset:]) > self.connector.max_size_file_upload_recv:
                                         raise CustomException(f'{self.connector.source_id} cannot receive too large file of size'
                                                         f' {len(binary[binary_offset:])}')                                    
                                                                         
@@ -528,18 +537,40 @@ class FullDuplex:
                                                                             f'{dst_filename_fullpath}, ignoring...')
                                                             unify_chunks = False
                                                     if unify_chunks:
+                                                        total_file_size = sum([os.path.getsize(chunk) for chunk in files_to_unify])
+                                                        if total_file_size > self.connector.max_size_file_upload_recv:
+                                                            self.logger.warning(f'{self.connector.source_id} cannot receive too large file of size'
+                                                                            f' {total_file_size}')
+                                                            unify_chunks = False
+                                                            
+                                                    if unify_chunks:                                                        
                                                         self.logger.info(f'{self.connector.source_id} handle_incoming_connection from '
                                                                         f'peer {self.peername} unifying chunks {files_to_unify} '
-                                                                        f'into file {dst_filename_fullpath}')                                                    
-                                                        fdunify = open(dst_filename_fullpath, 'wb')                                            
-                                                        for thefile in files_to_unify:
-                                                            with open(thefile, 'rb') as fdread:
-                                                                ffread = True
-                                                                while ffread:
-                                                                    ffread = fdread.read(self.connector.READ_CHUNK_SIZE)
-                                                                    fdunify.write(ffread)
-                                                            await asyncio.sleep(0)
-                                                        ffread = None
+                                                                        f'into file {dst_filename_fullpath}')   
+                                                        fdunify = open(dst_filename_fullpath, 'wb')
+                                                        stderr_data = fallback_manual_cat = None
+                                                        try:
+                                                            cat_proc = await asyncio.create_subprocess_exec('cat',
+                                                                    *files_to_unify, stdout=fdunify, stderr=asyncio.subprocess.PIPE)
+                                                            stdout_data, stderr_data = await cat_proc.communicate()
+                                                            if stderr_data:
+                                                                self.logger.info(f'{self.connector.source_id} Error using cat : '
+                                                                             f'{stderr_data[:100]}, fallback to manual cat')                                                                
+                                                                fallback_manual_cat = True
+                                                        except Exception as excu:
+                                                            self.logger.warning(f'{self.connector.source_id} Error unifying : '
+                                                                                 f'{excu}, fallback to manual cat')
+                                                            fallback_manual_cat = True
+                                                            
+                                                        if fallback_manual_cat:                                                                                                       
+                                                            for thefile in files_to_unify:
+                                                                with open(thefile, 'rb') as fdread:
+                                                                    ffread = True
+                                                                    while ffread:
+                                                                        ffread = fdread.read(self.connector.READ_CHUNK_SIZE)
+                                                                        fdunify.write(ffread)
+                                                                await asyncio.sleep(0)
+                                                            ffread = None
                                                         fdunify.close()
                                                     #delete chunks
                                                     for thefile in files_to_unify:
@@ -574,9 +605,18 @@ class FullDuplex:
                                                       'handle_incoming_connection with_file removal')
                                     
                         else:
-                            self.logger.warning(f'{self.connector.source_id} handle_incoming_connection from peer '
+                            if dst_dirpath is not False:
+                                self.logger.warning(f'{self.connector.source_id} handle_incoming_connection from peer '
                                                 f'{self.peername} tried to create file in non existing directory '
                                                 f'{dst_dirpath} for type {with_file.get("dst_type")}, ignoring...')
+                            if binary:
+                                binary_offset = with_file.get('binary_offset', 0)                            
+                                #remove file from binary, whether having written it to dst_fullpath or not. To prevent bloating
+                                binary = binary[:binary_offset]
+                                if len(binary) == 0:
+                                    if MessageFields.WITH_BINARY in transport_json:
+                                        del transport_json[MessageFields.WITH_BINARY]
+                            
                     
                     #check if this message is a response to an awaiting request, and update put_msg_to_queue_recv
                     response_id = transport_json.get(MessageFields.RESPONSE_ID)                                
@@ -678,7 +718,7 @@ class FullDuplex:
                     try:
                         with open(file_src_path, 'rb') as fd:
                             binary_file = fd.read()
-                        if len(binary_file) > self.connector.max_size_file_upload:
+                        if len(binary_file) > self.connector.max_size_file_upload_send:
                             raise Exception(f'{self.connector.source_id} cannot send too large file of size {len(binary_file)}')
                     except Exception as exc:
                         self.logger.exception('handle_outgoing_connection handling file : '+str(file_src_path))
@@ -901,7 +941,8 @@ class FullDuplex:
                     #common_name = cert_der["subject"][1][0][1]
                     #if common_name == ssl.DEFAULT_CLIENT_CERTIFICATE_COMMON_NAME:                         
                     crt_path, key_path = await self.connector.ssl_helper.create_client_certificate(source_id=\
-                                                            transport_json[MessageFields.SOURCE_ID], common_name=None)
+                                            transport_json[MessageFields.SOURCE_ID], common_name=None,
+                                            hook_allow_certificate_creation=self.connector.hook_allow_certificate_creation)
                     with open(crt_path, 'r') as fd:
                         crt = fd.read()
                     with open(key_path, 'r') as fd:
